@@ -62,8 +62,12 @@ distr_pluce_worth_mean <- function(f) {
     old_seed <- .Random.seed
     set.seed(13)
     for (i in 1:t) {
-      y_rand <- distr_pluce_worth_random(t = 1e3, f = f[i, , drop = FALSE])
-      res_mean[i, ] <- colMeans(y_rand)
+      if (all(is.finite(f[i, ])) && all(f[i, ] > 1e-12) && all(f[i, ] < 1e12)) {
+        y_rand <- distr_pluce_worth_random(t = 1e3, f = f[i, , drop = FALSE])
+        res_mean[i, ] <- colMeans(y_rand)
+      } else {
+        res_mean[i, ] <- NA_real_
+      }
     }
     .Random.seed <- old_seed
   }
@@ -94,8 +98,12 @@ distr_pluce_worth_var <- function(f) {
     old_seed <- .Random.seed
     set.seed(13)
     for (i in 1:t) {
-      y_rand <- distr_pluce_worth_random(t = 1e3, f = f[i, , drop = FALSE])
-      res_var[i, , ] <- stats::cov(y_rand)
+      if (all(is.finite(f[i, ])) && all(f[i, ] > 1e-12) && all(f[i, ] < 1e12)) {
+        y_rand <- distr_pluce_worth_random(t = 1e3, f = f[i, , drop = FALSE])
+        res_var[i, , ] <- stats::cov(y_rand)
+      } else {
+        res_var[i, , ] <- NA_real_
+      }
     }
     .Random.seed <- old_seed
   }
@@ -148,10 +156,14 @@ distr_pluce_worth_fisher <- function(f) {
     old_seed <- .Random.seed
     set.seed(13)
     for (i in 1:t) {
-      y_rand <- distr_pluce_worth_random(t = 1e3, f = f[i, , drop = FALSE])
-      for (j in 1:nrow(y_rand)) {
-        score <- distr_pluce_worth_score(y = y_rand[j, , drop = FALSE], f = f[i, , drop = FALSE])
-        res_fisher[i, , ] <- res_fisher[i, , ] + t(score) %*% score / nrow(y_rand)
+      if (all(is.finite(f[i, ])) && all(f[i, ] > 1e-12) && all(f[i, ] < 1e12)) {
+        y_rand <- distr_pluce_worth_random(t = 1e3, f = f[i, , drop = FALSE])
+        for (j in 1:nrow(y_rand)) {
+          score <- distr_pluce_worth_score(y = y_rand[j, , drop = FALSE], f = f[i, , drop = FALSE])
+          res_fisher[i, , ] <- res_fisher[i, , ] + t(score) %*% score / nrow(y_rand)
+        }
+      } else {
+        res_fisher[i, , ] <- NA_real_
       }
     }
     .Random.seed <- old_seed
@@ -164,6 +176,8 @@ distr_pluce_worth_fisher <- function(f) {
 # Random Generation Function ---------------------------------------------------
 distr_pluce_worth_random <- function(t, f) {
   n <- length(f)
+  f <- pmax(pmin(1e12, f), 1e-12)
+  f[is.na(f)] <- 1
   w <- f / prod(f)^(1 / n)
   res_random <- t(replicate(Matrix::invPerm(sample(1:n, replace = FALSE, prob = w)), n = t))
   return(res_random)
